@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use strictures 2;
@@ -44,15 +44,14 @@ sub _build_pool_code {
     return sub { return $self->pool->[ int rand @{ $self->pool } ] };
 };
 
-
-has min_size => (
+has _min_size => (
     is       => 'ro',
     builder  => 1,
     lazy     => 1,
     init_arg => undef,
 );
 
-sub _build_min_size {
+sub _build__min_size {
     my ($self) = @_;
 
     my @sizes = map { $self->_duration($_) } @{ $self->pool };
@@ -82,7 +81,7 @@ sub motif {
         my $diff = $self->size - $sum;
 
         last
-            if sprintf( $format, $diff ) < sprintf( $format, $self->min_size );
+            if sprintf( $format, $diff ) < sprintf( $format, $self->_min_size );
 
         next
             if sprintf( $format, $size ) > sprintf( $format, $diff );
@@ -125,7 +124,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -152,8 +151,8 @@ version 0.0400
 
   $score->write_score('motif.mid');
 
-  # The pool may also be MIDI durations
-  my $mdp = Music::Duration::Partition->new(
+  # The pool may also be made of MIDI durations
+  $mdp = Music::Duration::Partition->new(
     size => 100,
     pool => [qw/ d50 d25 /],
   );
@@ -186,11 +185,14 @@ Default: C<4> (4 quarter notes = 1 whole note)
 
   $pool = $mdp->pool;
 
-The list of possible note duration names to use in constructing a
-motif.
+The list of possible note durations to use in constructing a motif.
 
 Default: C<[ keys %MIDI::Simple::Length ]> (wn, hn, qn, ...)
 
+This can be B<either> a list of duration names, as in the default
+example, or duration values, specified with a preceding 'd'.  A
+mixture of both is not well defined. YMMV
+
 =head2 pool_code
 
   $name = $mdp->pool_code->();
@@ -201,12 +203,6 @@ B<pool>.
 
 Default: Random item of B<pool>
 
-=head2 min_size
-
-  $min_size = $mdp->min_size;
-
-Smallest B<pool> duration.  This is a computed attribute.
-
 =head2 verbose
 
   $verbose = $mdp->verbose;
